@@ -85,9 +85,9 @@ def get_top_terms(tfidf, n):
 
 def doc_to_vec(doc_prep):
     document_vec = {}
-    length = sum(doc_prep.values())
+    document_norm = norm(doc_prep)
     for term in doc_prep:
-        document_vec[term] = doc_prep[term] / length
+        document_vec[term] = doc_prep[term] / document_norm
     return document_vec
 
 
